@@ -93,7 +93,7 @@ impl<S> SqsConsumer<S>
                 wait_time_seconds: Some(1),
                 ..Default::default()
             }
-        ).compat().await?;
+        ).with_timeout(Duration::from_secs(2)).compat().await?;
 
 
 
